# ifndef yyOptimization
# define yyOptimization

# if defined __STDC__ | defined __cplusplus
# define ARGS(parameters)	parameters
# else
# define ARGS(parameters)	()
# endif

# ifndef rbool
# define rbool char
# endif

# include "Tree.h"
# include "Definitions.h"


extern void (* Optimization_Exit) ARGS ((void));

extern void Optimization ARGS ((tTree t));

extern void BeginOptimization ARGS ((void));
extern void CloseOptimization ARGS ((void));

# endif
